Manual Schema Inclusion
=======================

This page demonstrates manual schema inclusion using the schema directive with JSONCrack visualization.

User Creation Schema
--------------------

.. schema:: User.create
   :title: User Creation Schema
   :description: Schema for creating new users
   :render_mode: onclick
   :direction: RIGHT
   :height: 500

Data Processing Schema with Auto-load
-------------------------------------

.. schema:: process_data
   :title: Data Processing Schema
   :description: Schema for processing data
   :render_mode: onload
   :direction: DOWN
   :height: 600

User Update Schema with Different Direction
-------------------------------------------

.. schema:: User.update
   :title: User Update Schema 
   :description: Schema for updating existing users
   :render_mode: onscreen
   :direction: LEFT
   :theme: dark
